| Title: | Extracts Knowledge from 'Git' Repositories |
|---|---|
| Description: | Scan multiple 'Git' repositories, pull specified files content and process it with large language models. You can summarize the content in specific way, extract information and data, or find answers to your questions about the repositories. The output can be stored in vector database and used for semantic search or as a part of a RAG (Retrieval Augmented Generation) prompt. |
| Authors: | Kamil Wais [aut, cre], Krystian Igras [aut], Maciej Banas [aut] |
| Maintainer: | Kamil Wais <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-06-06 10:05:20 UTC |
| Source: | https://github.com/r-world-devs/gitai |
Scan multiple 'Git' repositories, pull specified files content and process it with large language models. You can summarize the content in specific way, extract information and data, or find answers to your questions about the repositories. The output can be stored in vector database and used for semantic search or as a part of a RAG (Retrieval Augmented Generation) prompt.
Maintainer: Kamil Wais [email protected]
Authors:
Krystian Igras [email protected]
Maciej Banas [email protected]
Useful links:
GitAI object.Add files to GitAI object.
add_files(gitai, files)add_files(gitai, files)
gitai |
A |
files |
A character vector of file paths. May be defined with regular expression. |
A GitAI object.
Finding top K records in a vector database.
find_records(gitai, query, top_k = 1, verbose = is_verbose())find_records(gitai, query, top_k = 1, verbose = is_verbose())
gitai |
A |
query |
A character, user query. |
top_k |
A numeric, number of top K records to return. |
verbose |
A logical. If |
GitAI project.Initialize a GitAI project.
initialize_project(project_id)initialize_project(project_id)
project_id |
A character, ID of the project. |
A GitAI object.
GitAI is verboseThe function searches for GITAI_VERBOSE environmental variable
and tries to read it value as logical.
is_verbose()is_verbose()
A logical. Default is TRUE.
This function is meant to fix 'Namespaces in Imports field not imported from:' R check note. The note shows up when namespace is used to create package object (not function) or within file marked at '.Rbuildignore' file.
missing_deps_note_fix()missing_deps_note_fix()
GitAI repositories contentRun LLM on GitAI repositories content
process_repos(gitai, depth = 1, verbose = is_verbose())process_repos(gitai, depth = 1, verbose = is_verbose())
gitai |
A |
depth |
A numeric, maximum depth of folders to process. |
verbose |
A logical. If |
A list.
GitAI object.Setting database in GitAI object.
set_database(gitai, provider = "Pinecone", ...)set_database(gitai, provider = "Pinecone", ...)
gitai |
A |
provider |
A string. Name of database provider. |
... |
Additional arguments to pass to database provider constructor. |
GitAI object.Set GitHub repositories in GitAI object.
set_github_repos(gitai, ..., verbose = is_verbose())set_github_repos(gitai, ..., verbose = is_verbose())
gitai |
A |
... |
Parameters to pass to |
verbose |
A logical. If |
A GitAI object.
GitAI object.Set GitLab repositories in GitAI object.
set_gitlab_repos(gitai, ..., verbose = is_verbose())set_gitlab_repos(gitai, ..., verbose = is_verbose())
gitai |
A |
... |
Parameters to pass to |
verbose |
A logical. If |
A GitAI object.
GitAI object.Set Large Language Model in GitAI object.
set_llm(gitai, provider = "openai", ...) get_llm_defaults(provider)set_llm(gitai, provider = "openai", ...) get_llm_defaults(provider)
gitai |
A |
provider |
Name of LLM provider, a string. Results with setting up LLM using
|
... |
Other arguments to pass to corresponding |
A GitAI object.
Set prompt.
set_prompt(gitai, system_prompt)set_prompt(gitai, system_prompt)
gitai |
A |
system_prompt |
A system prompt. |
A GitAI object.
GitAI to be quiet.The function sets the GITAI_VERBOSE environmental variable
to FALSE.
verbose_off()verbose_off()
GitAI to be verboseThe function sets the GITAI_VERBOSE environmental variable
to TRUE.
verbose_on()verbose_on()